@@ -49,6 +49,7 @@
              (gnu packages kerberos)
              (gnu packages gnupg)
              (gnu packages texinfo)
+             (gnu packages python)
              (gnu packages pkg-config)
              (gnu packages base))
 
@@ -86,6 +87,50 @@ applications.")
     (home-page "https://www.libssh.org")
     (license license:lgpl2.1+)))
 
+(define-public libssh8-0
+  (package
+   (inherit libssh10)
+   (name "libssh")
+   (version "0.8.0")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append "https://www.libssh.org/files/"
+                                (version-major+minor version)
+                                "/libssh-" version ".tar.xz"))
+            (sha256
+             (base32
+              "1amgzvabl835vvzyv08hr05ak2ksp4jncbfnm2i0ayspf3b5qdg0"))))
+   (native-inputs (list python))))
+
+(define-public libssh8-1
+  (package
+   (inherit libssh10)
+   (name "libssh")
+   (version "0.8.1")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append "https://www.libssh.org/files/"
+                                (version-major+minor version)
+                                "/libssh-" version ".tar.xz"))
+            (sha256
+             (base32
+              "090r1fq8p89rwfv2x3wji3kyz31bf0z9mlv6pq7nrr55niki4zyi"))))
+   (native-inputs (list python))))
+
+(define-public libssh8
+  (package
+   (inherit libssh10)
+   (name "libssh")
+   (version "0.8.3")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append "https://www.libssh.org/files/"
+                                (version-major+minor version)
+                                "/libssh-" version ".tar.xz"))
+            (sha256
+             (base32
+              "1l19pl0l8lp00a8yawvf2yp8xhb4fjgsdmvprv9qqdpj0vv32brh")))) ))
+
 (define-public libssh9
   (package
     (inherit libssh)
@@ -100,6 +145,20 @@ applications.")
                (base32
                 "19f7h8s044pqfhfk35ky5lj4hvqhi2p2p46xkwbcsqz6jllkqc15"))))))
 
+(define-public libssh11
+  (package
+   (inherit libssh)
+   (name "libssh")
+   (version "0.11.1")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append "https://www.libssh.org/files/"
+                                (version-major+minor version)
+                                "/libssh-" version ".tar.xz"))
+            (sha256
+             (base32
+              "0y8v5ihrqnjxchvjhz8fcczndchaaxxim64bqm8q3q4i5v3xrdql"))))))
+
 (define-public guile-ssh
   (package
     (name "guile-ssh")
@@ -167,6 +226,27 @@ programs written in GNU Guile interpreter.  It is a wrapper to the underlying
 libssh library.")
     (license license:gpl3+)))
 
+(define-public guile-ssh/libssh8-0
+  (package
+   (inherit guile-ssh)
+   (name "guile-ssh")
+   (inputs (modify-inputs (package-inputs guile-ssh)
+                          (replace "libssh" libssh8-0)))))
+
+(define-public guile-ssh/libssh8-1
+  (package
+   (inherit guile-ssh)
+   (name "guile-ssh")
+   (inputs (modify-inputs (package-inputs guile-ssh)
+                          (replace "libssh" libssh8-1)))))
+
+(define-public guile-ssh/libssh8
+  (package
+   (inherit guile-ssh)
+   (name "guile-ssh")
+   (inputs (modify-inputs (package-inputs guile-ssh)
+                          (replace "libssh" libssh8)))))
+
 (define-public guile-ssh/libssh9
   (package
    (inherit guile-ssh)
@@ -174,10 +254,27 @@ libssh library.")
    (inputs (modify-inputs (package-inputs guile-ssh)
              (replace "libssh" libssh9)))))
 
+(define-public guile-ssh/libssh11
+  (package
+   (inherit guile-ssh)
+   (name "guile-ssh")
+   (inputs (modify-inputs (package-inputs guile-ssh)
+                          (replace "libssh" libssh11)))))
+
 
 
-(if (getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_9")
-    guile-ssh/libssh9
-    guile-ssh)
+(cond
+ ((getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_8_0")
+  guile-ssh/libssh8-0)
+ ((getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_8_1")
+  guile-ssh/libssh8-1)
+ ((getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_8")
+  guile-ssh/libssh8)
+ ((getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_9")
+  guile-ssh/libssh9)
+ ((getenv "GUILE_SSH_BUILD_WITH_LIBSSH_0_11")
+  guile-ssh/libssh11)
+ (else
+  guile-ssh))
 
 ;;; guix.scm ends here.
