@@ -1,4 +1,4 @@
-/* Copyright (C) 2013, 2014 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+/* Copyright (C) 2013-2020 Artyom V. Poptsov <poptsov.artyom@gmail.com>
  *
  * This file is part of Guile-SSH
  *
@@ -21,18 +21,36 @@
 
 #include <libguile.h>
 #include <libssh/libssh.h>
+#include <libssh/callbacks.h>
+
+#include "common.h"
+
+
+extern gssh_port_t channel_tag;
 
 
 /* Smob data. */
-struct channel_data {
+struct gssh_channel {
   /* Reference to the parent session.  We need to keep the reference
      to prevent the session from premature freeing by the GC. */
   SCM session;
 
   ssh_channel ssh_channel;
   uint8_t is_stderr;
+
+  /* When a remote side is closed a channel this flag is set to 1. */
+  uint8_t is_remote_closed;
+
+  /* libssh channel callbacks. */
+  struct ssh_channel_callbacks_struct* callbacks;
+
+  /* libssh channel poll timeout.  This timeout passed to the poll(2)
+     procedure. */
+  int32_t timeout;
 };
 
+typedef struct gssh_channel gssh_channel_t;
+
 /* Make sure that the channel data is valid.  Throw `guile-ssh-error' if the
    channel SCM has been closed and freed. */
 #define GSSH_VALIDATE_CHANNEL_DATA(cd, scm, fn)                         \
@@ -71,10 +89,9 @@ extern void init_channel_type (void);
 
 
 /* Helper procedures */
-extern struct channel_data *_scm_to_channel_data (SCM x);
-extern SCM _scm_from_channel_data (ssh_channel ch, SCM session,
-                                   long flags);
+extern gssh_channel_t *gssh_channel_from_scm (SCM x);
+extern SCM ssh_channel_to_scm (ssh_channel ch, SCM session, long flags);
 
-int _gssh_channel_parent_session_connected_p (struct channel_data* cd);
+int _gssh_channel_parent_session_connected_p (gssh_channel_t* cd);
 
 #endif /* ifndef __CHANNEL_TYPE_H__ */
