@@ -26,6 +26,7 @@
 
 #include "common.h"
 #include "session-type.h"
+#include "session-func.h"
 #include "server-type.h"
 #include "message-type.h"
 #include "error.h"
@@ -40,7 +41,7 @@ enum gssh_server_options {
 
 
 /* SSH server options mapping to Guile symbols. */
-struct symbol_mapping server_options[] = {
+gssh_symbol_t server_options[] = {
   { "bindaddr",           SSH_BIND_OPTIONS_BINDADDR       },
   { "bindport",           SSH_BIND_OPTIONS_BINDPORT       },
   { "hostkey",            SSH_BIND_OPTIONS_HOSTKEY        },
@@ -108,9 +109,9 @@ set_blocking_mode (ssh_bind bind, SCM value)
 /* Convert Scheme symbol to libssh constant and set the corresponding
    option to the value of the constant. */
 static inline int
-set_sym_opt (ssh_bind bind, int type, struct symbol_mapping *sm, SCM value)
+set_sym_opt (ssh_bind bind, int type, gssh_symbol_t *sm, SCM value)
 {
-  const struct symbol_mapping *opt = _scm_to_ssh_const (sm, value);
+  const gssh_symbol_t *opt = gssh_symbol_from_scm (sm, value);
   if (! opt)
     guile_ssh_error1 ("server-set!", "Wrong value", value);
   return ssh_bind_options_set (bind, type, &opt->value);
@@ -155,13 +156,13 @@ Return value is undefined.\
 ")
 #define FUNC_NAME s_guile_ssh_server_set_x
 {
-  struct server_data *server_data = _scm_to_server_data (server);
-  const struct symbol_mapping *opt;		  /* Server option */
+  gssh_server_t *server_data = gssh_server_from_scm (server);
+  const gssh_symbol_t *opt;		  /* Server option */
   int res;
 
   SCM_ASSERT (scm_is_symbol (option), option, SCM_ARG2, FUNC_NAME);
 
-  opt = _scm_to_ssh_const (server_options, option);
+  opt = gssh_symbol_from_scm (server_options, option);
 
   if (! opt)
     guile_ssh_error1 (FUNC_NAME, "No such option", option);
@@ -193,8 +194,8 @@ not set.  Throw `guile-ssh-error' on error.\
 ")
 #define FUNC_NAME s_guile_ssh_server_get
 {
-  const struct server_data *sd     = _scm_to_server_data (server);
-  const struct symbol_mapping *opt = _scm_to_ssh_const (server_options, option);
+  const gssh_server_t *sd     = gssh_server_from_scm (server);
+  const gssh_symbol_t *opt = gssh_symbol_from_scm (server_options, option);
 
   if (! opt)
     guile_ssh_error1 (FUNC_NAME, "No such option", option);
@@ -212,7 +213,7 @@ Return value is undefined.\
 ")
 #define FUNC_NAME s_guile_ssh_server_listen
 {
-  struct server_data *server_data = _scm_to_server_data (server);
+  gssh_server_t *server_data = gssh_server_from_scm (server);
   int res = ssh_bind_listen (server_data->bind);
 
   _gssh_log_debug_format(FUNC_NAME, server, "result: %d", res);
@@ -232,9 +233,9 @@ Throw `guile-ssh-error' on error.  Return a new SSH session.\
 ")
 #define FUNC_NAME s_guile_ssh_server_accept
 {
-  struct server_data *server_data   = _scm_to_server_data (server);
+  gssh_server_t *server_data   = gssh_server_from_scm (server);
   SCM session = guile_ssh_make_session ();
-  struct session_data *session_data = _scm_to_session_data (session);
+  gssh_session_t *session_data = gssh_session_from_scm (session);
   int res = ssh_bind_accept (server_data->bind, session_data->ssh_session);
 
   _gssh_log_debug_format(FUNC_NAME, server, "result: %d", res);
@@ -256,7 +257,7 @@ Return value is undefined.\
 ")
 #define FUNC_NAME s_guile_ssh_server_handle_key_exchange
 {
-  struct session_data *session_data = _scm_to_session_data (session);
+  gssh_session_t *session_data = gssh_session_from_scm (session);
   int res = ssh_handle_key_exchange (session_data->ssh_session);
 
   _gssh_log_debug_format(FUNC_NAME, session, "result: %d", res);
@@ -276,23 +277,13 @@ SCM_DEFINE (guile_ssh_server_message_get,
 Get a message.\
 ")
 {
-  SCM smob;
-  struct session_data *session_data = _scm_to_session_data (session);
-  struct message_data *message_data
-    = (struct message_data *) scm_gc_malloc (sizeof (struct message_data),
-                                             "message");
+  gssh_session_t *session_data = gssh_session_from_scm (session);
+  ssh_message message = ssh_message_get (session_data->ssh_session);
 
-  message_data->message = ssh_message_get (session_data->ssh_session);
-  if (! message_data->message)
-    {
-      scm_gc_free (message_data, sizeof (struct message_data), "message");
-      return SCM_BOOL_F;
-    }
-
-  message_data->session = session;
-
-  SCM_NEWSMOB (smob, message_tag, message_data);
-  return smob;
+  if (message == NULL)
+    return SCM_BOOL_F;
+  else
+    return ssh_message_to_scm (message, session);
 }
 
 
