@@ -1,6 +1,7 @@
 /* session-func.c -- Functions for working with SSH session.
  *
  * Copyright (C) 2013-2024 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+ * Copyright (C) 2024 Peter Tillemans <pti@snamellit.com>
  *
  * This file is part of Guile-SSH.
  *
@@ -66,9 +67,18 @@ static gssh_symbol_t session_options[] = {
   { "stricthostkeycheck", SSH_OPTIONS_STRICTHOSTKEYCHECK },
   { "compression",        SSH_OPTIONS_COMPRESSION        },
   { "compression-level",  SSH_OPTIONS_COMPRESSION_LEVEL  },
+#if HAVE_LIBSSH_0_9
+  /* This option was added only in 0.9.0 (commit
+     79f0c38fbd767f578d7b87fae15fb64faad32aab) */
+  { "process-config?",    SSH_OPTIONS_PROCESS_CONFIG     },
+#else
+#  warning Option SSH_OPTIONS_PROCESS_CONFIG is not available.
+#endif
 
 #if HAVE_LIBSSH_0_8_1
   { "nodelay",            SSH_OPTIONS_NODELAY            },
+#else
+#  warning Option SSH_OPTIONS_NODELAY is not available.
 #endif
 
 #if HAVE_LIBSSH_0_8_3
@@ -79,10 +89,14 @@ static gssh_symbol_t session_options[] = {
      This option was added to the libssh in
      4521ab73b6858efa0083ac96a1775719b1f649ae */
   { "public-key-accepted-types", SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES },
+#else
+#  warning Option SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES is not available.
 #endif
 
 #if HAVE_LIBSSH_0_10
   {"rsa-min-size",        SSH_OPTIONS_RSA_MIN_SIZE       },
+#else
+#  warning Option SSH_OPTIONS_RSA_MIN_SIZE is not available.
 #endif
 
   { "callbacks",          GSSH_OPTIONS_CALLBACKS         },
@@ -234,12 +248,12 @@ set_int32_opt (ssh_session session, int type, SCM value)
 static inline int
 set_bool_opt (ssh_session session, int type, SCM value)
 {
-  int32_t bool;
+  int32_t bool_value;
 
   SCM_ASSERT (scm_is_bool (value), value, SCM_ARG3, "session-set!");
 
-  bool = scm_to_bool (value);
-  return ssh_options_set (session, type, &bool);
+  bool_value = scm_to_bool (value);
+  return ssh_options_set (session, type, &bool_value);
 }
 
 /* Convert VALUE to a socket file descriptor and pass it to
@@ -383,6 +397,13 @@ set_option (SCM scm_session, gssh_session_t* sd, int type, SCM value)
     case SSH_OPTIONS_SSH1:
     case SSH_OPTIONS_SSH2:
     case SSH_OPTIONS_STRICTHOSTKEYCHECK:
+
+#if HAVE_LIBSSH_0_9
+        /* This option was added only in 0.9.0 (commit
+           79f0c38fbd767f578d7b87fae15fb64faad32aab) */
+    case SSH_OPTIONS_PROCESS_CONFIG:
+#endif
+
 #if HAVE_LIBSSH_0_8_1
     case SSH_OPTIONS_NODELAY:
 #endif
@@ -394,15 +415,6 @@ set_option (SCM scm_session, gssh_session_t* sd, int type, SCM value)
     case GSSH_OPTIONS_CALLBACKS:
       return set_callbacks (scm_session, sd, value);
 
-#if ! HAVE_LIBSSH_0_8_3
-    case SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES:
-        guile_ssh_error1 ("session-set!",
-                          "Option 'public-key-accepted-types' is not available"
-                          " in the current version of libssh (%s)",
-                          ssh_version (0));
-        break;
-#endif
-
 #if HAVE_LIBSSH_0_10
     case SSH_OPTIONS_RSA_MIN_SIZE:
         return set_int32_opt (session, type, value);
