@@ -21,12 +21,15 @@
 
 #include <libguile.h>
 
+extern SCM guile_ssh_make_session (void);
+extern SCM guile_ssh_is_session_p (SCM arg1);
 extern SCM guile_ssh_blocking_flush (SCM arg1, SCM arg2);
 extern SCM guile_ssh_session_set (SCM arg1, SCM arg2, SCM arg3);
 extern SCM guile_ssh_session_get (SCM arg1, SCM arg2);
 extern SCM guile_ssh_get_version (SCM arg1);
 extern SCM guile_ssh_is_connected_p (SCM arg1);
 extern SCM guile_ssh_connect_x (SCM arg1);
+extern SCM guile_ssh_disconnect (SCM session);
 extern SCM guile_ssh_authenticate_server (SCM arg1);
 
 extern void init_session_func (void);
