@@ -1,6 +1,6 @@
 /* version.c -- Get information about versions.
  *
- * Copyright (C) 2013 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+ * Copyright (C) 2013-2022 Artyom V. Poptsov <poptsov.artyom@gmail.com>
  *
  * This file is part of Guile-SSH.
  *
@@ -23,6 +23,8 @@
 #include <libguile.h>
 #include <libssh/libssh.h>
 
+#include "config.h"
+
 /* Get version of the libssh. */
 SCM_DEFINE (guile_ssh_get_libssh_version, "%get-libssh-version", 0, 0, 0,
             (),
@@ -42,6 +44,18 @@ SCM_DEFINE (guile_ssh_get_library_version, "get-library-version", 0, 0, 0,
   return scm_from_locale_string (PACKAGE_VERSION);
 }
 
+
+SCM_DEFINE (gssh_dsa_supported_p, "dsa-support?", 0, 0, 0,
+            (),
+            "\
+Check if DSA keys are enabled.\
+")
+#define FUNC_NAME s_gssh_dsa_supported_p
+{
+    return scm_from_bool (ENABLE_DSA);
+}
+#undef FUNC_NAME
+
 
 void
 init_version (void)
