@@ -1,6 +1,6 @@
 ;;; client-server.scm -- Guile-SSH client is SUT.
 
-;; Copyright (C) 2014, 2015, 2016 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+;; Copyright (C) 2014, 2015, 2016, 2024 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 ;;
 ;; This file is a part of Guile-SSH.
 ;;
@@ -34,6 +34,7 @@
              (ssh channel)
              (ssh log)
              (ssh tunnel)
+             (ssh version)
              (srfi srfi-4)
              (tests common))
 
@@ -396,6 +397,16 @@
         (userauth-public-key! session (public-key-from-file %rsakey-pub)))))))
 
 
+(let* ((version (get-libssh-version))
+       (version (map string->number (string-split version #\.))))
+  (when (and (zero? (car version))
+             (or (= (cadr version) 7)
+                 (and (= (cadr version) 8)
+                      (< (caddr version) 3))))
+    ;; XXX: This test fails because of the problems with ECDSA public key
+    ;; authentication in libssh versions prior 0.8.3.
+    (test-skip "userauth-public-key!, success")))
+
 (test-equal-with-log "userauth-public-key!, success"
   'success
   (run-client-test
@@ -417,6 +428,33 @@
         (let ((prvkey (private-key-from-file %ecdsakey)))
           (userauth-public-key! session prvkey)))))))
 
+(let* ((version (get-libssh-version))
+       (version (map string->number (string-split version #\.))))
+  (when (and (zero? (car version))
+             (>= (cadr version) 9))
+    (test-skip "userauth-public-key!, success (RSA)")))
+
+(test-equal-with-log "userauth-public-key!, success (RSA)"
+  'success
+  (run-client-test
+
+   ;; server
+   (lambda (server)
+     (server-listen server)
+     (let ((session (server-accept server)))
+       (server-handle-key-exchange session)
+       (start-session-loop session
+                           (lambda (msg)
+                             (message-reply-success msg)))))
+
+   ;; client
+   (lambda ()
+     (call-with-connected-session
+      (lambda (session)
+        (authenticate-server session)
+        (let ((prvkey (private-key-from-file %rsakey)))
+          (userauth-public-key! session prvkey)))))))
+
 
 ;;; 'userauth-public-key/auto!'
 
@@ -754,9 +792,9 @@
                     (loop (cons result data)
                           (get-bytevector-n channel (/ vect-size 2))))
                   (lambda err
-                    (format (current-error-port)
-                            "    unexpected error: ~a~%"
-                            err)
+                    (format-log/scm 'nolog
+                                    "data transferring, remote side abruptly closed"
+                                    "err: ~a" err)
                     #f))))))))))
 
 
