@@ -1,6 +1,6 @@
 ;;; key.scm -- Testing of Guile-SSH keys
 
-;; Copyright (C) 2014-2022 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+;; Copyright (C) 2014-2024 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 ;;
 ;; This file is a part of Guile-SSH.
 ;;
@@ -70,7 +70,8 @@
   (private-key-from-file %ecdsakey))
 
 (define *rsa-pub-key*   (public-key-from-file %rsakey-pub))
-(define *dsa-pub-key*   (public-key-from-file %dsakey-pub))
+(define *dsa-pub-key*   (and (dsa-support?)
+                             (public-key-from-file %dsakey-pub)))
 (define *ecdsa-pub-key* (when-openssl
                          (public-key-from-file %ecdsakey-pub)))
 
@@ -245,6 +246,23 @@
 
 ;;; Check reading encrypted keys.
 
+(let* ((version (get-libssh-version))
+       (version (map string->number (string-split version #\.))))
+  (format-log/scm 'nolog "none" "***** version: ~a ~a ~a~%" (car version) (cadr version) (caddr version))
+  ;; XXX: libssh 0.8.0 version components:
+  ;;   LIBSSH_VERSION_MAJOR  0
+  ;;   LIBSSH_VERSION_MINOR  7
+  ;;   LIBSSH_VERSION_MICRO  90
+  (when (and (zero? (car version))
+             (or (= (cadr version) 7)
+                 (and (= (cadr version) 8)
+                      (< (caddr version) 3))))
+    ;; XXX: Those tests fails with ""Unsupported private key method ssh-rsa"
+    ;; error as support for keys in openssh container format (other than
+    ;; ed25519) was added only in 0.8.3.
+    (test-skip "encrypted key: RSA")
+    (test-skip "encrypted key: RSA: access denied")))
+
 (test-assert-with-log "encrypted key: RSA"
   (private-key-from-file %rsakey-encrypted
                          #:auth-callback (lambda (prompt max-len echo? verify? userdata)
