@@ -222,17 +222,28 @@
   (make-session #:host   "localhost"
                 #:config %config))
 
-(test-assert "make-session, '#:config' as a boolean value"
+(test-assert "make-session, '#:config' set to '/dev/null'"
+  (make-session #:host   "localhost"
+                #:config "/dev/null"))
+
+;; Setting '#:config' option to #f must set "process-config?" option to #f.
+(test-assert "make-session, '#:config' as a boolean value: #f"
   (make-session #:host   "localhost"
                 #:config #f))
 
+;; Setting '#:config' option to #t must initiate parsing the default user
+;; configuration file ('~/.ssh/config'.)
+(test-assert "make-session, '#:config' as a boolean value: #t"
+  (make-session #:host   "localhost"
+                #:config #t))
+
 (test-error "make-session, only '#:config' is specified"
   'guile-ssh-error
   (make-session #:config %config))
 
 (test-equal "make-session: keywords must overwrite config options"
   22
-  (let ((s (make-session #:host   "localhost"
+  (let ((s (make-session #:host   "example"
                          #:port   22
                          ;; Configuration sets port to 2222
                          #:config %config)))
