@@ -75,10 +75,24 @@
      (call-with-connected-session/shell
       (lambda (session)
         (receive (result exit-code)
-            (pgrep session "guile --listen=37146" #:full? #t)
+            (pgrep session "process-1")
           (and (zero? exit-code)
-               (string=? "pgrep -f 'guile --listen=37146'"
-                         (car result)))))))))
+               (not (null? result))
+               (car result))))))))
+
+(test-equal-with-log "pgrep, guile"
+  '(12345)
+  (run-client-test
+   (lambda (server)
+     (start-server/exec server
+                        (lambda (session message channel)
+                          (write-line "$1 = (12345)\n" channel))))
+   (lambda ()
+     (call-with-connected-session/shell
+      (lambda (session)
+        (receive (result exit-code)
+            (pgrep session "process-2" #:use-guile? #t)
+          result))))))
 
 (test-assert-with-log "command-available?"
   (run-client-test
@@ -89,18 +103,6 @@
       (lambda (session)
         (command-available? session "guile"))))))
 
-(test-assert-with-log "fallback-pgrep"
-  (run-client-test
-   (lambda (server)
-     (start-server/exec server (const #t)))
-   (lambda ()
-     (call-with-connected-session/shell
-      (lambda (session)
-        (receive (result exit-code)
-            (fallback-pgrep session "guile")
-          (and (zero? exit-code)
-               result)))))))
-
 (test-assert-with-log "loadavg"
   (run-client-test
    (lambda (server)
@@ -113,9 +115,10 @@
 
 
 ;;;
+(define exit-status (test-runner-fail-count (test-runner-current)))
 
 (test-end "shell")
 
-(exit (= (test-runner-fail-count (test-runner-current)) 0))
+(exit (= 0 exit-status))
 
 ;;; shell.scm ends here.
